@@ -29,9 +29,14 @@ class CookieManager:
         },
     )
     _keys = {}  # Signing/verification keys in the format {"key_id": "key")
+    cookie_name = None
 
     def __init__(
-        self, keys: dict, config: dict = None, logger=None, exceptions=None
+        self,
+        keys: dict,
+        config: dict = None,
+        logger=None,
+        exceptions=None,
     ) -> None:
         if config:
             self._config = self._override_config(override_config=config)
@@ -125,7 +130,7 @@ class CookieManager:
         try:
             self._logger.debug(f"Beginning verification: {cookie}")
             cookie_value = TimestampSigner(verify_key).unsign(
-                value=cookie, max_age=self._config.get("VERIFY_MAX_COOKIE_AGE", 50)
+                cookie, max_age=self._config.get("VERIFY_MAX_COOKIE_AGE", 50)
             )
         except BadSignature as e:
             self._logger.warning(
